"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBlockAlignment = getBlockAlignment;
exports.styleWholeSelectedBlocksModifier = styleWholeSelectedBlocksModifier;
exports.getEditorData = getEditorData;
exports.extendSelectionByData = extendSelectionByData;
exports.getEntitiesByBlockKey = getEntitiesByBlockKey;
exports.getEntities = getEntities;
exports.findEntityInSelection = findEntityInSelection;
exports.createEntity = createEntity;
exports.removeEntity = removeEntity;
exports.findEntities = findEntities;
exports.confirmLink = confirmLink;
exports.removeLink = removeLink;
exports.getSelectionCoords = exports.getSelectionRange = void 0;

var _draftJs = require("draft-js");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var getSelectionRange = function getSelectionRange() {
  var selection = window.getSelection();
  if (selection.rangeCount === 0) return null;
  return selection.getRangeAt(0);
};

exports.getSelectionRange = getSelectionRange;

var getSelectionCoords = function getSelectionCoords(toolbar, selectionRange) {
  var editorBounds = toolbar.closest('.editor-container').getBoundingClientRect();
  var rangeBounds = selectionRange.getBoundingClientRect();
  var rangeWidth = rangeBounds.right - rangeBounds.left;
  var content = toolbar.querySelector('.toolbar-items');
  var outOfViewPort = content.offsetWidth / 2 > rangeBounds.left + rangeBounds.width / 2;
  var offsetTop = rangeBounds.top - editorBounds.top - (content.offsetHeight + 5);
  var offsetLeft = rangeBounds.left - editorBounds.left + rangeWidth / 2 - content.offsetWidth / 2;
  return {
    arrowPosition: outOfViewPort ? "".concat(rangeBounds.left + rangeBounds.width / 2, "px") : '50%',
    coords: {
      left: outOfViewPort ? -editorBounds.left : offsetLeft,
      top: offsetTop
    }
  };
};

exports.getSelectionCoords = getSelectionCoords;

function getBlockAlignment(block) {
  var style = 'left';
  block.findStyleRanges(function (e) {
    if (e.hasStyle('center')) style = 'center';
    if (e.hasStyle('right')) style = 'right';
  });
  return style;
}

function styleWholeSelectedBlocksModifier(editorState, style) {
  var removeStyles = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
  var currentContent = editorState.getCurrentContent();
  var selection = editorState.getSelection();
  var focusBlock = currentContent.getBlockForKey(selection.getFocusKey());
  var anchorBlock = currentContent.getBlockForKey(selection.getAnchorKey());
  var selectionIsBackward = selection.getIsBackward();
  var changes = {
    anchorOffset: 0,
    focusOffset: focusBlock.getLength()
  };

  if (selectionIsBackward) {
    changes = {
      focusOffset: 0,
      anchorOffset: anchorBlock.getLength()
    };
  }

  var selectWholeBlocks = selection.merge(changes);

  var modifiedContent = _draftJs.Modifier.applyInlineStyle(currentContent, selectWholeBlocks, style);

  var finalContent = removeStyles.reduce(function (content, style) {
    return _draftJs.Modifier.removeInlineStyle(content, selectWholeBlocks, style);
  }, modifiedContent);
  return _draftJs.EditorState.push(editorState, finalContent, 'change-inline-style');
}

function getEditorData(editorState) {
  return {
    contentState: editorState.getCurrentContent(),
    inlineStyle: editorState.getCurrentInlineStyle(),
    selectionState: editorState.getSelection(),
    hasFocus: editorState.getSelection().getHasFocus(),
    isCollapsed: editorState.getSelection().isCollapsed(),
    startKey: editorState.getSelection().getStartKey(),
    startOffset: editorState.getSelection().getStartOffset(),
    endKey: editorState.getSelection().getEndKey(),
    endOffset: editorState.getSelection().getEndOffset()
  };
}

function extendSelectionByData(editorState, data) {
  var _getEditorData = getEditorData(editorState),
      selectionState = _getEditorData.selectionState,
      startKey = _getEditorData.startKey,
      startOffset = _getEditorData.startOffset,
      endKey = _getEditorData.endKey,
      endOffset = _getEditorData.endOffset;

  var anchorKey = startKey;
  var focusKey = endKey;
  var anchorOffset = startOffset;
  var focusOffset = endOffset;
  data.forEach(function (_ref, key) {
    var blockKey = _ref.blockKey,
        start = _ref.start,
        end = _ref.end;

    if (key === 0) {
      anchorKey = blockKey;
      anchorOffset = start;
    }

    if (key === data.length - 1) {
      focusKey = blockKey;
      focusOffset = end;
    }
  });
  var state = Object.assign({}, anchorKey ? {
    anchorKey: anchorKey
  } : {}, {
    focusKey: focusKey,
    anchorOffset: anchorOffset,
    focusOffset: focusOffset,
    isBackward: false
  });
  var newSelectionState = selectionState.merge(state);
  return _draftJs.EditorState.acceptSelection(editorState, newSelectionState);
}

function getEntitiesByBlockKey(editorState) {
  var entityType = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var blockKey = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  return getEntities(editorState, entityType).filter(function (entity) {
    return entity.blockKey === blockKey;
  });
}

function getEntities(editorState) {
  var entityType = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var selectedEntityKey = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

  var _getEditorData2 = getEditorData(editorState),
      contentState = _getEditorData2.contentState;

  var entities = [];
  contentState.getBlocksAsArray().forEach(function (block) {
    var selectedEntity = null;
    block.findEntityRanges(function (character) {
      var entityKey = character.getEntity();

      if (entityKey !== null) {
        var entity = contentState.getEntity(entityKey);

        if (!entityType || entityType && entity.getType() === entityType) {
          if (selectedEntityKey === null || selectedEntityKey !== null && entityKey === selectedEntityKey) {
            selectedEntity = {
              entityKey: entityKey,
              blockKey: block.getKey(),
              entity: contentState.getEntity(entityKey)
            };
            return true;
          } else {
            return false;
          }
        }
      }

      return false;
    }, function (start, end) {
      entities.push(_objectSpread(_objectSpread({}, selectedEntity), {}, {
        start: start,
        end: end
      }));
    });
  });
  return entities;
}

function findEntityInSelection(editorState, entityType) {
  var _getEditorData3 = getEditorData(editorState),
      startKey = _getEditorData3.startKey,
      startOffset = _getEditorData3.startOffset,
      endOffset = _getEditorData3.endOffset;

  var entities = getEntitiesByBlockKey(editorState, entityType, startKey);
  if (entities.length === 0) return null;
  var selectedEntity = null;
  entities.forEach(function (entity) {
    var blockKey = entity.blockKey,
        start = entity.start,
        end = entity.end;

    if (blockKey === startKey && (startOffset > start && startOffset < end || endOffset > start && endOffset < end || startOffset === start && endOffset === end)) {
      selectedEntity = entity;
    }
  });
  return selectedEntity;
}

function createEntity(editorState, entityType) {
  var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var _getEditorData4 = getEditorData(editorState),
      contentState = _getEditorData4.contentState,
      selectionState = _getEditorData4.selectionState;

  var contentStateWithEntity = contentState.createEntity(entityType, 'MUTABLE', data);
  var entityKey = contentStateWithEntity.getLastCreatedEntityKey();

  var newEditorState = _draftJs.EditorState.set(editorState, {
    currentContent: _draftJs.Modifier.applyEntity(contentStateWithEntity, selectionState, entityKey)
  });

  return newEditorState;
}

function getSelectedBlocks(editorState) {
  var _getEditorData5 = getEditorData(editorState),
      contentState = _getEditorData5.contentState,
      startKey = _getEditorData5.startKey,
      endKey = _getEditorData5.endKey;

  var blocks = [];
  var block = contentState.getBlockForKey(startKey); // eslint-disable-next-line no-constant-condition

  while (true) {
    blocks.push(block);
    var blockKey = block.getKey();

    if (blockKey === endKey) {
      break;
    } else {
      block = contentState.getBlockAfter(blockKey);
    }
  }

  return blocks;
}

function getSelectedBlocksByType(editorState, blockType) {
  var _getEditorData6 = getEditorData(editorState),
      contentState = _getEditorData6.contentState,
      startKey = _getEditorData6.startKey,
      endKey = _getEditorData6.endKey,
      startOffset = _getEditorData6.startOffset,
      endOffset = _getEditorData6.endOffset;

  var blocks = [];
  getSelectedBlocks(editorState).forEach(function (block) {
    var blockKey = block.getKey();
    var blockStartOffset = blockKey === startKey ? startOffset : 0;
    var blockEndOffset = blockKey === endKey ? endOffset : block.getLength();
    findEntities(blockType, block, function (start, end) {
      if (Math.max(start, blockStartOffset) <= Math.min(end, blockEndOffset)) {
        var entityKey = block.getEntityAt(start);
        var text = block.getText().slice(start, end);
        var url = contentState.getEntity(entityKey).getData().url;
        blocks.push({
          text: text,
          url: url,
          block: block,
          start: start,
          end: end
        });
      }
    }, contentState);
  });
  return blocks;
}

function removeEntity(editorState, entityType) {
  var _getEditorData7 = getEditorData(editorState),
      contentState = _getEditorData7.contentState,
      selectionState = _getEditorData7.selectionState;

  var blocks = getSelectedBlocksByType(editorState, entityType);

  if (blocks.length !== 0) {
    var anchorKey;
    var focusKey;
    var anchorOffset;
    var focusOffset;
    blocks.forEach(function (_ref2, key) {
      var block = _ref2.block,
          start = _ref2.start,
          end = _ref2.end;
      var blockKey = block.getKey();

      if (key === 0) {
        anchorKey = blockKey;
        anchorOffset = start;
      }

      if (key === blocks.length - 1) {
        focusKey = blockKey;
        focusOffset = end;
      }
    });

    var newContentState = _draftJs.Modifier.applyEntity(contentState, selectionState.merge({
      anchorKey: anchorKey,
      focusKey: focusKey,
      anchorOffset: anchorOffset,
      focusOffset: focusOffset,
      isBackward: false
    }), null);

    return _draftJs.EditorState.set(editorState, {
      currentContent: newContentState
    });
  }
}

function getEntity(character) {
  return character.getEntity();
}

function entityFilter(character, entityType, contentState) {
  var entityKey = getEntity(character);
  return entityKey !== null && contentState.getEntity(entityKey).getType() === entityType;
}

function findEntities(entityType, contentBlock, callback, contentState) {
  return contentBlock.findEntityRanges(function (character) {
    return entityFilter(character, entityType, contentState);
  }, callback);
}

function confirmLink(editorState, url) {
  var contentState = editorState.getCurrentContent();
  var contentStateWithEntity = contentState.createEntity('LINK', 'MUTABLE', {
    url: url
  });
  return _draftJs.EditorState.set(editorState, {
    currentContent: contentStateWithEntity
  });
}

function removeLink(editorState) {
  var selection = editorState.getSelection();

  if (!selection.isCollapsed()) {
    return _draftJs.RichUtils.toggleLink(editorState, selection, null);
  } else {
    return editorState;
  }
}